pub struct Nsec3HashAlgorithm(/* private fields */);Expand description
NSEC3 hash algorithm numbers.
This type selects the algorithm used to hash domain names for use with the NSEC3.
For the currently registered values see the IANA registration. This type is complete as of 2008-03-05.
Implementations
Sourceimpl Nsec3HashAlgorithm
impl Nsec3HashAlgorithm
Sourcepub const SHA1: Nsec3HashAlgorithm
pub const SHA1: Nsec3HashAlgorithm
Specifies that the SHA-1 hash function is used.
Sourceimpl Nsec3HashAlgorithm
impl Nsec3HashAlgorithm
pub const COMPOSE_LEN: u16 = <u8 as crate::base::wire::Compose>::COMPOSE_LEN
Sourcepub const fn from_int(value: u8) -> Nsec3HashAlgorithm
pub const fn from_int(value: u8) -> Nsec3HashAlgorithm
Returns a value from its raw integer value.
Sourcepub fn from_mnemonic(m: &[u8]) -> Option<Nsec3HashAlgorithm>
pub fn from_mnemonic(m: &[u8]) -> Option<Nsec3HashAlgorithm>
Returns a value from a well-defined mnemonic.
Sourcepub const fn to_mnemonic(self) -> Option<&'static [u8]>
pub const fn to_mnemonic(self) -> Option<&'static [u8]>
Returns the mnemonic for this value if there is one.
This will also return a mnemonic if a well-defined variant
is hidden in a Int variant.
Sourcepub const fn to_mnemonic_str(self) -> Option<&'static str>
pub const fn to_mnemonic_str(self) -> Option<&'static str>
Returns the mnemonic as a &str for this value if there is one
pub fn parse<'a, Octs>( parser: &mut Parser<'a, Octs>, ) -> Result<Nsec3HashAlgorithm, ParseError>
pub fn compose<Target>(
&self,
target: &mut Target,
) -> Result<(), <Target as OctetsBuilder>::AppendError>where
Target: OctetsBuilder + ?Sized,
Sourceimpl Nsec3HashAlgorithm
impl Nsec3HashAlgorithm
pub fn from_bytes(bytes: &[u8]) -> Option<Nsec3HashAlgorithm>