pub enum PushError {
CountOverflow,
LimitExceeded,
ShortBuf,
}Expand description
An error occurred when attempting to add data to a message.
Variants
CountOverflow
Push attempted to exceed a hard limit.
For example, attempting to put more than 65,535 records in the question, answer, authority or additional section of a DNS message.
LimitExceeded
Push attempted to exceed a soft limit.
ShortBuf
Push attempted to exceed the capacity of a buffer.