ExtendedError

Struct ExtendedError 

pub struct ExtendedError<Octs> { /* private fields */ }
Option data for an extended DNS error.

The Extended DNS Error option allows a server to include more detailed information in a response to a failed query why it did. It contains a standardized ExtendedErrorCode for machines and an optional UTF-8 error text for humans.

Implementations

Source

impl<Octs> ExtendedError<Octs>

pub fn new( code: ExtendedErrorCode, text: Option<Str<Octs>>, ) -> Result<ExtendedError<Octs>, LongOptData>
where Octs: AsRef<[u8]>,

Creates a new value from a code and optional text.

Returns an error if text is present but is too long to fit into an option.

pub fn new_with_str( code: ExtendedErrorCode, text: &str, ) -> Result<ExtendedError<Octs>, LongOptData>

pub unsafe fn new_unchecked( code: ExtendedErrorCode, text: Option<Result<Str<Octs>, Octs>>, ) -> ExtendedError<Octs>

Creates a new value without checking for the option length.

Safety

The caller must ensure that the length of the wire format of the value does not exceed 65,535 octets.

pub fn code(&self) -> ExtendedErrorCode

Returns the error code.

pub fn text(&self) -> Option<Result<&Str<Octs>, &Octs>>

Returns the text.

If there is no text, returns None. If there is text and it is correctly encoded UTF-8, returns Some(Ok(_)). If there is text but it is not UTF-8, returns Some(Err(_)).

pub fn text_slice(&self) -> Option<&[u8]>
where Octs: AsRef<[u8]>,

Returns the text as an octets slice.

pub fn set_text(&mut self, text: Str<Octs>)

Sets the text field.

pub fn is_private(&self) -> bool

Returns true if the code is in the private range.

pub fn parse<'a, Src>( parser: &mut Parser<'a, Src>, ) -> Result<ExtendedError<Octs>, ParseError>
where Src: Octets<Range<'a> = Octs> + ?Sized, Octs: AsRef<[u8]>,