KeyTag

Struct KeyTag 

pub struct KeyTag<Octs>
where Octs: ?Sized,
{ /* private fields */ }
Option data for the edns-key-tag option.

This option allows a client to indicate the key tags of the trust anchor keys they are using to validate responses. The option contains a sequence of key tags.

Implementations

Source

impl<Octs> KeyTag<Octs>

pub fn from_octets(octets: Octs) -> Result<KeyTag<Octs>, ParseError>
where Octs: AsRef<[u8]>,

Creates a new value from its content in wire format.

The function returns an error if the octets do not encode a valid edns-key-tag option: the length needs to be an even number of octets and no longer than 65,536 octets.

pub unsafe fn from_octets_unchecked(octets: Octs) -> KeyTag<Octs>

Creates a new value from its wire-format content without checking.

Safety

The caller needs to ensure that octets is a valid key tag. The length needs to be an even number of octets and no longer than 65,536 octets.

pub fn parse<'a, Src>( parser: &mut Parser<'a, Src>, ) -> Result<KeyTag<Octs>, ParseError>
where Src: Octets<Range<'a> = Octs> + ?Sized,

Source

impl KeyTag<[u8]>

pub fn from_slice(slice: &[u8]) -> Result<&KeyTag<[u8]>, ParseError>

Creates a key tag value from a slice.

Returns an error if slice does not contain a valid key tag.

pub unsafe fn from_slice_unchecked(slice: &[u8]) -> &KeyTag<[u8]>

Creates a key tag value from a slice without checking.

Safety

The caller needs to ensure that slice contains a valid key tag. The length needs to be an even number of octets and no longer than 65,536 octets.

Source

impl<Octs> KeyTag<Octs>
where Octs: ?Sized,

pub fn as_octets(&self) -> &Octs

Returns a reference to the underlying octets.

The octets contain the key tag value in its wire format: a sequence of u16 in network byte order.

pub fn into_octets(self) -> Octs
where Octs: Sized,

Converts the value to the underlying octets.

The octets contain the key tag value in its wire format: a sequence of u16 in network byte order.

pub fn as_slice(&self) -> &[u8]
where Octs: AsRef<[u8]>,

Returns a slice of the underlying octets.

The slice will contain the key tag value in its wire format: a sequence of u16 in network byte order.

pub fn as_slice_mut(&mut self) -> &mut [u8]
where Octs: AsMut<[u8]>,

Returns a mutable slice of the underlying octets.

The slice will contain the key tag value in its wire format: a sequence of u16 in network byte order.

pub fn iter(&self) -> KeyTagIter<'_>
where Octs: AsRef<[u8]>,

Returns an iterator over the individual key tags.