pub struct OptionHeader { /* private fields */ }Expand description
The header of an OPT option.
This header contains a 16 bit option code identifying the kind of option we are dealing with and a 16 bit length describing the lenngth in octets of the option data.
Implementations
Sourceimpl OptionHeader
impl OptionHeader
Sourcepub fn new(code: u16, len: u16) -> OptionHeader
pub fn new(code: u16, len: u16) -> OptionHeader
Creates a new option header from code and length.
pub fn parse<Octs>( parser: &mut Parser<'_, Octs>, ) -> Result<OptionHeader, ParseError>