Padding

Struct Padding 

pub struct Padding<Octs>
where Octs: ?Sized,
{ /* private fields */ }
Option data for the padding option.

This option is used to increase the size of a DNS message to a fixed value so eavesdropper can’t dertermine information from the size.

Generally, you should not need to use this type. Instead, you can use the OptBuilder::padding and [OptBuilder::random_padding] methods to add padding to a message – and ignore it when receving one.

The option is defined in RFC 7830.

Implementations

Source

impl Padding<()>

pub const CODE: OptionCode = OptionCode::PADDING

The option code for this option.

Source

impl<Octs> Padding<Octs>

pub fn from_octets(octets: Octs) -> Result<Padding<Octs>, LongOptData>
where Octs: AsRef<[u8]>,

Creates a value from the padding octets.

Returns an error if octets are longer than 65,535 octets.

pub unsafe fn from_octets_unchecked(octets: Octs) -> Padding<Octs>

Creates a value from the padding octets without checking.

Safety

The caller needs to ensure that octets are not longer than 65,535 octets.

pub fn parse<'a, Src>( parser: &mut Parser<'a, Src>, ) -> Result<Padding<Octs>, ParseError>
where Src: Octets<Range<'a> = Octs> + ?Sized,

Parses a value from its wire formal.

Source

impl<Octs> Padding<Octs>
where Octs: ?Sized,

pub fn as_octets(&self) -> &Octs

Returns a reference to the padding octets.

pub fn into_octets(self) -> Octs
where Octs: Sized,

Converts the value into the padding octets.

pub fn as_slice(&self) -> &[u8]
where Octs: AsRef<[u8]>,

Returns a slice of the padding octets.