HeaderSection

Struct HeaderSection 

pub struct HeaderSection { /* private fields */ }
The complete header section of a DNS message.

Consists of a Header directly followed by a HeaderCounts.

You can create an owned value via the new function or the Default trait and acquire a pointer referring the the header section of an existing DNS message via the for_message_slice or for_message_slice_mut functions.

Implementations

Source

impl HeaderSection

Creation and Conversion

pub fn new() -> HeaderSection

Creates a new header section.

The value will have all header and header counts fields set to zero or false.

pub fn for_message_slice(s: &[u8]) -> &HeaderSection

Creates a reference from the octets slice of a message.

Panics

This function panics if the octets slice is shorter than 12 octets.

pub fn for_message_slice_mut(s: &mut [u8]) -> &mut HeaderSection

Creates a mutable reference from the octets slice of a message.

Panics

This function panics if the octets slice is shorter than 12 octets.

pub fn as_slice(&self) -> &[u8]

Returns a reference to the underlying octets slice.

Source

impl HeaderSection

Access to Header and Counts

pub fn header(&self) -> &Header

Returns a reference to the header.

pub fn header_mut(&mut self) -> &mut Header

Returns a mutable reference to the header.

pub fn counts(&self) -> &HeaderCounts

Returns a reference to the header counts.

pub fn counts_mut(&mut self) -> &mut HeaderCounts

Returns a mutable reference to the header counts.

Source

impl HeaderSection

Parsing and Composing

pub fn parse<Octs>( parser: &mut Parser<'_, Octs>, ) -> Result<HeaderSection, ParseError>
where Octs: AsRef<[u8]>,

pub fn compose<Target>( &self, target: &mut Target, ) -> Result<(), <Target as OctetsBuilder>::AppendError>
where Target: OctetsBuilder + ?Sized,