pub enum RecordDataChain<T, U> {
This(T),
Next(U),
}Expand description
A custom struct allowing to chain together multiple custom record data types.
Allows e.g. using the custom Txt struct from above and chain it with domain’s AllRecordData,
Variants