pub struct Host<'a> {
pub hostname: &'a str,
pub ipv4: Ipv4Addr,
pub ipv6: Ipv6Addr,
pub ttl: Ttl,
}Expand description
A simple representation of a host that can be used to generate mDNS answers.
This structure implements the HostAnswers trait, which allows it to be used
as a responder for mDNS queries coming from other network peers.
Fields
hostname: &'a strThe name of the host. I.e. a name “foo” will be pingable as “foo.local”
ipv4: Ipv4AddrThe IPv4 address of the host.
Leaving it as Ipv4Addr::UNSPECIFIED means that the host will not aswer it to A queries.
ipv6: Ipv6AddrThe IPv6 address of the host.
Leaving it as Ipv6Addr::UNSPECIFIED means that the host will not aswer it to AAAA queries.
ttl: TtlThe time-to-live of the mDNS answers.