ServiceAnswers

Struct ServiceAnswers 

pub struct ServiceAnswers<'a> { /* private fields */ }
A wrapper around a Service that also provides the Host of the service and thus allows the HostAnswers trait contract to be fullfilled for a Service instance.

Implementations

Source

impl<'a> ServiceAnswers<'a>

pub const fn new(host: &'a Host<'a>, service: &'a Service<'a>) -> Self

Create a new ServiceAnswers instance.