pub struct Service<'a> {
pub name: &'a str,
pub priority: u16,
pub weight: u16,
pub service: &'a str,
pub protocol: &'a str,
pub port: u16,
pub service_subtypes: &'a [&'a str],
pub txt_kvs: &'a [(&'a str, &'a str)],
}Expand description
A simple representation of a DNS-SD service that can be used to generate mDNS answers.
This structure (indirectly - via the ServiceAnswers wraper which also provides the hostname)
implements the HostAnswers trait, which allows it to be used as a responder for mDNS queries
coming from other network peers.
Fields
name: &'a strThe name of the service. I.e. “printer”
priority: u16The priority of the service.
weight: u16The weight of the service.
service: &'a strThe service type. I.e. “_http”
protocol: &'a strThe protocol of the service. I.e. “_tcp” or “_udp”
port: u16The TCP/UDP port where the service listens for incoming requests.
service_subtypes: &'a [&'a str]The subtypes of the service, if any.
txt_kvs: &'a [(&'a str, &'a str)]The key-value pairs that will be included in the TXT record, as per the DNS-SD spec.