pub struct ServiceAnswers<'a> { /* private fields */ }Expand description
A wrapper around a Service that also provides the Host of the service
and thus allows the HostAnswers trait contract to be fullfilled for a Service instance.
Implementations